aospy: automated climate data analysis and management
=====================================================

.. image:: https://readthedocs.org/projects/pip/badge/?version=stable
   :target: http://pip.pypa.io/en/stable/?badge=stable
   :alt: ReadTheDocs Status
.. image:: https://travis-ci.org/spencerahill/aospy.svg?branch=develop
   :target: https://travis-ci.org/spencerahill/aospy
   :alt: Travis CI Status
.. image:: https://ci.appveyor.com/api/projects/status/4o448ga560sudry9?svg=true
   :target: https://ci.appveyor.com/project/spencerahill/aospy
   :alt: AppVeyor Status
.. image:: https://coveralls.io/repos/github/spencerahill/aospy/badge.svg?branch=develop
   :target: https://coveralls.io/github/spencerahill/aospy?branch=develop
   :alt: Coveralls Status

aospy is a Python-based tool for automating computations involving
gridded climate data and the management of the results of those
computations.

Please visit our documentation for futher information:
http://aospy.readthedocs.io

Troubleshooting
---------------

Questions of any kind are welcome and best placed as Issues on the
Github repo.

Copyright and license
---------------------

Copyright 2017, the aospy developers.  

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

.. image:: docs/aospy_logo.png
   :alt: aospy logo
   :align: center
   :height: 300px
   :width: 300px
   :name: aospy-logo

